Checkit class abstract

Main entry point to build validators.

Use static methods to get strongly-typed nodes like Checkit.string or Checkit.num.

Constructors

Checkit()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

config ValidatorConfig
Global config used to build context for each node. You can override this to set global settings.
getter/setter pair
dateTime DateTimeNode<DateTime>
Creates a DateTimeNode validator.
no setter
double DoubleNode<double>
Creates a DoubleNode validator.
no setter
int IntNode<int>
Creates a IntNode validator.
no setter
num NumNode<num>
Creates a NumNode validator.
no setter
string StringNode<String>
Creates a StringNode validator.
no setter