DateTimeValidator class abstract

Constructors

DateTimeValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

after(DateTime date, {String? error}) Validator<DateTime>
before(DateTime date, {String? error}) Validator<DateTime>
leapYear({String? error}) Validator<DateTime>
maxYear(int max, {String? error}) Validator<DateTime>
minYear(int min, {String? error}) Validator<DateTime>
notFuture({String? error}) Validator<DateTime>
notPast({String? error}) Validator<DateTime>
range(DateTime start, DateTime end, {bool inclusive = false, String? error}) Validator<DateTime>
weekday({String? error}) Validator<DateTime>
weekend({String? error}) Validator<DateTime>