IpValidator class abstract

Constructors

IpValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inSubnet(String cidr, {String? error}) Validator<String>
ip({String? error}) Validator<String>
linkLocal({String? error}) Validator<String>
localhost({String? error}) Validator<String>
loopback({String? error}) Validator<String>
range(String startIp, String endIp, {String? error}) Validator<String>
v4({String? error}) Validator<String>
v6({String? error}) Validator<String>