PasswordValidator class abstract

Constructors

PasswordValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hasDigit({String? error}) Validator<String>
hasLetter({String? error}) Validator<String>
hasLowercase({String? error}) Validator<String>
hasSpecial({String? allowedChars, String? error}) Validator<String>
hasUppercase({String? error}) Validator<String>
noRepeats({String? error}) Validator<String>
noSpace({String? error}) Validator<String>
simple({String? error}) Validator<String>
strong({String? error}) Validator<String>
typical({String? error}) Validator<String>