after method

StringDateNode<String> after(
  1. String date, {
  2. String? error,
})

Requires the date to be after a specific date.

If the input date is less than or equal to the date, validation fails.

Example:

final validator = Checkit.string.dateTime('yyyy-MM-dd').after('2020-01-01').build();

print(validator.validate('2021-01-01').isValid); // true
print(validator.validate('2019-12-31').isValid); // false

Implementation

StringDateNode after(String date, {String? error}) {
  _validators.add(StringDateValidator.after(date, error: error));

  return this;
}