StringValidator class abstract

Constructors

StringValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alpha({String? error}) Validator<String>
alphanumeric({String? error}) Validator<String>
contains(String data, {String? error}) Validator<String>
email({String? error}) Validator<String>
endsWith(String suffix, {String? error}) Validator<String>
equals(String expectedString, {String? error}) Validator<String>
exact(int length, {String? error}) Validator<String>
hasRepeats({String? error}) Validator<String>
hasSymbols(String symbols, {String? error}) Validator<String>
isDouble({String? error}) Validator<String>
isInt({String? error}) Validator<String>
jwt({String? error}) Validator<String>
max(int length, {String? error}) Validator<String>
min(int length, {String? error}) Validator<String>
pattern(String pattern, {String? error}) Validator<String>
range(int min, int max, {String? error, bool includeMin = true, bool includeMax = true}) Validator<String>
startsWith(String suffix, {String? error}) Validator<String>