GeneralValidator class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
any<
T> (List< Validator< validators, {String? error}) → Validator<T> >T> -
custom<
T> (bool validate(T value, ValidationContext context), {String error = ''}) → Validator< T> -
every<
T> (List< Validator< validators, {String? error}) → Validator<T> >T> -
not<
T> (Validator< T> validator, {String? error}) → Validator<T> -
notNull(
{String? error}) → Validator< Object?> -
wrapAdvanced(
AdvancedValidator validator, {String? error}) → Validator< Object?>