IntValidator class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
digitCount(
int count, {String? error}) → Validator< int> -
divisibleBy(
int divisor, {String? error}) → Validator< int> -
even(
{String? error}) → Validator< int> -
odd(
{String? error}) → Validator< int> -
oneOf(
Set< int> allowedValues, {String? error}) → Validator<int> -
prime(
{String? error}) → Validator< int> -
rangeWithStep(
int min, int max, int step, {String? error, bool includeMin = true, bool includeMax = true}) → Validator< int>