NumValidator class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
max(
num max, {String? error, bool inclusive = true}) → Validator< num> -
min(
num min, {String? error, bool inclusive = true}) → Validator< num> -
multiple(
num factor, {String? error}) → Validator< num> -
negative(
{String? error}) → Validator< num> -
positive(
{String? error}) → Validator< num> -
range(
num min, num max, {String? error, bool includeMin = true, bool includeMax = true}) → Validator< num>