hasSpecial method
Requires at least one special character such as !@#\$%^&*.
You can restrict which characters are allowed using allowedChars.
Example:
Checkit.string.password().hasSpecial(allowedChars: '!@#');
Implementation
PasswordNode<T> hasSpecial({String? allowedChars, String? error}) {
_validators.add(
PasswordValidator.hasSpecial(allowedChars: allowedChars, error: error),
);
return this;
}